@@ -68,9 +68,7 @@ class ProcessingMixin:
         self.renderer_context = renderer_context
         self.prefix = prefix
         self.extra_types = extra_types
-        self.extra_types.update(
-            getattr(settings, 'DRF_REACT_TEMPLATE_TYPE_MAP', {})
-        )
+        self.extra_types.update(getattr(settings, 'DRF_REACT_TEMPLATE_TYPE_MAP', {}))
         self.TYPE_MAP.update(self.extra_types)
 
     def _get_type_map_value(self, field: SerializerType):
@@ -166,6 +164,11 @@ class SchemaProcessor(ProcessingMixin):
             result['items'] = self._get_field_properties(field.child, "")
             result['uniqueItems'] = True
         else:
+            if isinstance(field, serializers.CharField):
+                if field.min_length:
+                    result['minLength'] = field.min_length
+                if field.max_length:
+                    result['maxLength'] = field.max_length
             if field.allow_null:
                 result['type'] = [result['type'], 'null']
             enum = type_map_obj.get('enum')
